@@ -33,9 +33,10 @@
 #  define MESSAGECOMPOSER_DEPRECATED_NO_EXPORT MESSAGECOMPOSER_NO_EXPORT MESSAGECOMPOSER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define MESSAGECOMPOSER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef MESSAGECOMPOSER_NO_DEPRECATED
+#    define MESSAGECOMPOSER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
